@@ -22,14 +22,14 @@
 
 #include "kcoloredit.h"
 
-static const char *description =
+static const char description[] =
 	I18N_NOOP("KColorEdit");
 // INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
 
 
 static KCmdLineOptions options[] =
 {
-  { "+[File]", I18N_NOOP("file to open"), 0 },
+  { "+[File]", I18N_NOOP("File to open"), 0 },
   KCmdLineLastOption
   // INSERT YOUR COMMANDLINE OPTIONS HERE
 };
