@@ -1,10 +1,8 @@
+// -*- C++ -*-
 
 #ifndef _TEXFONT_PK_H
 #define _TEXFONT_PK_H
 
-#include <qstring.h>
-#include <stdio.h>
-
 #include "TeXFont.h"
 
 class glyph;
@@ -14,7 +12,7 @@ class TeXFont_PK : public TeXFont {
   TeXFont_PK(TeXFontDefinition *parent);
   ~TeXFont_PK();
   
-  glyph *getGlyph(Q_UINT16 character, bool generateCharacterPixmap=false, QColor color=Qt::black);
+  glyph* getGlyph(Q_UINT16 character, bool generateCharacterPixmap=false, const QColor& color=Qt::black);
 
  private:
   FILE         *file;		// open font file or NULL
@@ -33,8 +31,8 @@ class TeXFont_PK : public TeXFont {
   inline void read_PK_char(unsigned int ch);
   inline int  PK_get_nyb(FILE *fp);
   inline int  PK_packed_num(FILE *fp);
-  inline void read_PK_index(void);
-  inline void PK_skip_specials(void);
+  inline void read_PK_index();
+  inline void PK_skip_specials();
 };
 
 #endif
