@@ -5,13 +5,13 @@
 // (C) 2003 Stefan Kebekus
 // Distributed under the GPL
 
-#include <../config.h>
+#include <config.h>
 #ifdef HAVE_FREETYPE
 
 
 #include "fontEncodingPool.h"
 
-fontEncodingPool::fontEncodingPool(void)
+fontEncodingPool::fontEncodingPool()
 {
 }
 
