@@ -1,3 +1,4 @@
+// -*- C++ -*-
 // optionDialogSpecialWidget.h
 //
 // Part of KDVI - A DVI previewer for the KDE desktop environemt 
@@ -8,10 +9,9 @@
 #ifndef OPTIONDIALOGSPECIALWIDGET_H
 #define OPTIONDIALOGSPECIALWIDGET_H
 
-// Add header files alphabetically
-
 #include "optionDialogSpecialWidget_base.h"
 
+
 class optionDialogSpecialWidget : public optionDialogSpecialWidget_base
 { 
   Q_OBJECT
@@ -21,7 +21,7 @@ class optionDialogSpecialWidget : public optionDialogSpecialWidget_base
   ~optionDialogSpecialWidget();
   
  public slots:
-  void apply(void);
+  void apply();
   void slotComboBox(int item);
   void slotUserDefdEditorCommand( const QString &text );
   void slotExtraHelpButton( const QString &anchor);
