@@ -6,26 +6,30 @@
 // (C) 2004 Stefan Kebekus
 // Distributed under the GPL
 
+#include <config.h>
 
 #include <kdebug.h>
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprocio.h>
+#include <ktempfile.h>
+#include <kurl.h>
 #include <qdir.h>
 #include <qpainter.h>
-#include <stdio.h>
 
-#include "dviFile.h"
 #include "psgs.h"
+#include "dviFile.h"
+#include "pageNumber.h"
 
 extern const char psheader[];
 
 //#define DEBUG_PSGS
 
 
-pageInfo::pageInfo(QString _PostScriptString) {
+pageInfo::pageInfo(const QString& _PostScriptString) {
   PostScriptString = new QString(_PostScriptString);
-  background       = Qt::white;
+  background  = Qt::white;
+  permanentBackground = Qt::white;
 }
 
 
@@ -38,7 +42,7 @@ pageInfo::~pageInfo() {
 // ======================================================
 
 ghostscript_interface::ghostscript_interface() {
-  pageList.setAutoDelete(TRUE);
+  pageList.setAutoDelete(true);
 
   PostScriptHeaderString = new QString();
 
@@ -55,7 +59,7 @@ ghostscript_interface::~ghostscript_interface() {
 }
 
 
-void ghostscript_interface::setPostScript(PageNumber page, QString PostScript) {
+void ghostscript_interface::setPostScript(const PageNumber& page, const QString& PostScript) {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::setPostScript( " << page << ", ... )" << endl;
 #endif
@@ -79,27 +83,43 @@ void ghostscript_interface::setIncludePath(const QString &_includePath) {
 }
 
 
-void ghostscript_interface::setColor(PageNumber page, QColor background_color) {
+void ghostscript_interface::setBackgroundColor(const PageNumber& page, const QColor& background_color, bool permanent) {
 #ifdef DEBUG_PSGS
-  kdDebug(4300) << "ghostscript_interface::setColor( " << page << ", " << background_color << " )" << endl;
+  kdDebug(4300) << "ghostscript_interface::setBackgroundColor( " << page << ", " << background_color << " )" << endl;
 #endif
 
   if (pageList.find(page) == 0) {
     pageInfo *info = new pageInfo(QString::null);
     info->background = background_color;
+    if (permanent)
+      info->permanentBackground = background_color;
     // Check if dict is big enough
     if (pageList.count() > pageList.size() -2)
       pageList.resize(pageList.size()*2);
     pageList.insert(page, info);
-  } else
+  } else {
     pageList.find(page)->background = background_color;
+    if (permanent)
+      pageList.find(page)->permanentBackground = background_color;
+  }
 }
 
+void ghostscript_interface::restoreBackgroundColor(const PageNumber& page)
+{
+#ifdef DEBUG_PSGS
+  kdDebug(4300) << "ghostscript_interface::restoreBackgroundColor( " << page << " )" << endl;
+#endif
+  if (pageList.find(page) == 0)
+    return;
+
+  pageInfo *info = pageList.find(page);
+  info->background = info->permanentBackground;
+}
 
 // Returns the background color for a certain page. This color is
 // always guaranteed to be valid
 
-QColor ghostscript_interface::getBackgroundColor(PageNumber page) {
+QColor ghostscript_interface::getBackgroundColor(const PageNumber& page) const {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::getBackgroundColor( " << page << " )" << endl;
 #endif
@@ -111,7 +131,7 @@ QColor ghostscript_interface::getBackgroundColor(PageNumber page) {
 }
 
 
-void ghostscript_interface::clear(void) {
+void ghostscript_interface::clear() {
   PostScriptHeaderString->truncate(0);
   
   // Deletes all items, removes temporary files, etc.
@@ -119,7 +139,7 @@ void ghostscript_interface::clear(void) {
 }
 
 
-void ghostscript_interface::gs_generate_graphics_file(PageNumber page, const QString &filename, long magnification) {
+void ghostscript_interface::gs_generate_graphics_file(const PageNumber& page, const QString& filename, long magnification) {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::gs_generate_graphics_file( " << page << ", " << filename << " )" << endl;
 #endif
@@ -136,46 +156,53 @@ void ghostscript_interface::gs_generate_graphics_file(PageNumber page, const QSt
   // Generate a PNG-file
   // Step 1: Write the PostScriptString to a File
   KTempFile PSfile(QString::null,".ps");
-  FILE *f = PSfile.fstream();
 
-  fputs("%!PS-Adobe-2.0\n",f);
-  fputs("%%Creator: kdvi\n",f);
-  fputs("%%Title: KDVI temporary PostScript\n",f);
-  fputs("%%Pages: 1\n",f);
-  fputs("%%PageOrder: Ascend\n",f);
-  fprintf(f,"%%BoundingBox: 0 0 %ld %ld\n", 
-	  (long)(72*(pixel_page_w/resolution)), 
-	  (long)(72*(pixel_page_h/resolution)));  // HSize and VSize in 1/72 inch
-  fputs("%%EndComments\n",f);
-  fputs("%!\n",f);
+  QTextStream& os = *PSfile.textStream();
+  os << "%!PS-Adobe-2.0\n"
+     << "%%Creator: kdvi\n"
+     << "%%Title: KDVI temporary PostScript\n"
+     << "%%Pages: 1\n"
+     << "%%PageOrder: Ascend\n"
+        // HSize and VSize in 1/72 inch
+     << "%%BoundingBox: 0 0 "
+     << (Q_INT32)(72*(pixel_page_w/resolution)) << ' '
+     << (Q_INT32)(72*(pixel_page_h/resolution)) << '\n'
+     << "%%EndComments\n"
+     << "%!\n"
+     << psheader
+     << "TeXDict begin "
+        // HSize in (1/(65781.76*72))inch
+     << (Q_INT32)(72*65781*(pixel_page_w/resolution)) << ' '
+        // VSize in (1/(65781.76*72))inch 
+     << (Q_INT32)(72*65781*(pixel_page_h/resolution)) << ' '
+        // Magnification
+     << (Q_INT32)(magnification)
+        // dpi and vdpi
+     << " 300 300"
+        // Name
+     << " (test.dvi)"
+     << " @start end\n"
+     << "TeXDict begin\n"
+        // Start page
+     << "1 0 bop 0 0 a \n";
 
-  fputs(psheader,f);
-  fputs("TeXDict begin",f);
-
-  fprintf(f," %ld", (long)(72*65781*(pixel_page_w/resolution)) );  // HSize in (1/(65781.76*72))inch @@@
-  fprintf(f," %ld", (long)(72*65781*(pixel_page_h/resolution)) );  // VSize in (1/(65781.76*72))inch 
-  fprintf(f," %ld", magnification );  // Magnification
-  fputs(" 300 300",f);                        // dpi and vdpi
-  fputs(" (test.dvi)",f);                     // Name
-  fputs(" @start end\n",f);
-  fputs("TeXDict begin\n",f);
-
-  fputs("1 0 bop 0 0 a \n",f);                // Start page
   if (PostScriptHeaderString->latin1() != NULL)
-    fputs(PostScriptHeaderString->latin1(),f);
+    os << PostScriptHeaderString->latin1();
 
   if (info->background != Qt::white) {
     QString colorCommand = QString("gsave %1 %2 %3 setrgbcolor clippath fill grestore\n").
-      arg(info->background.red()).
-      arg(info->background.green()).
-      arg(info->background.blue());
-    fputs(colorCommand.latin1(),f);
+      arg(info->background.red()/255.0).
+      arg(info->background.green()/255.0).
+      arg(info->background.blue()/255.0);
+    os << colorCommand.latin1();
   }
 
   if (info->PostScriptString->latin1() != NULL)
-    fputs(info->PostScriptString->latin1(),f);
-  fputs("end\n",f);
-  fputs("showpage \n",f);
+    os << info->PostScriptString->latin1();
+
+  os << "end\n"
+     << "showpage \n";
+
   PSfile.close();
 
   // Step 2: Call GS with the File
@@ -251,15 +278,20 @@ void ghostscript_interface::gs_generate_graphics_file(PageNumber page, const QSt
 }
 
 
-void ghostscript_interface::graphics(PageNumber page, double dpi, long magnification, QPainter &paint) {
+void ghostscript_interface::graphics(const PageNumber& page, double dpi, long magnification, QPainter* paint) {
 #ifdef DEBUG_PSGS
   kdDebug(4300) << "ghostscript_interface::graphics( " << page << ", " << dpi << ", ... ) called." << endl;
 #endif
 
+  if (paint == 0) {
+    kdError(4300) << "ghostscript_interface::graphics(PageNumber page, double dpi, long magnification, QPainter *paint) called with paint == 0" << endl;
+    return;
+  }
+
   resolution   = dpi;
 
-  pixel_page_w = paint.viewport().width();
-  pixel_page_h = paint.viewport().height();
+  pixel_page_w = paint->viewport().width();
+  pixel_page_h = paint->viewport().height();
 
   pageInfo *info = pageList.find(page);
 
@@ -270,42 +302,39 @@ void ghostscript_interface::graphics(PageNumber page, double dpi, long magnifica
 #endif
     return;
   }
-  
-  KTempFile *GfxFile = new KTempFile(QString::null,".png");
-  GfxFile->setAutoDelete(1);
-  GfxFile->close(); // we are want the filename, not the file
-  
-  gs_generate_graphics_file(page, GfxFile->name(), magnification);
-  
-  QPixmap MemoryCopy(GfxFile->name());
-  paint.drawPixmap(0, 0, MemoryCopy);
+
+  KTempFile gfxFile(QString::null, ".png");
+  gfxFile.setAutoDelete(1);
+  gfxFile.close(); // we are want the filename, not the file
+
+  gs_generate_graphics_file(page, gfxFile.name(), magnification);
+
+  QPixmap MemoryCopy(gfxFile.name());
+  paint->drawPixmap(0, 0, MemoryCopy);
   return;
 }
 
 
-QString ghostscript_interface::locateEPSfile(const QString &filename, class dvifile *dvi)
+QString ghostscript_interface::locateEPSfile(const QString &filename, const KURL &base)
 {
-  QString EPSfilename(filename);
-
-  if (dvi == 0) {
-    kdError(4300) << "ghostscript_interface::locateEPSfile called with second argument == 0" << endl;
-    return EPSfilename;
+  // If the base URL indicates that the DVI file is local, try to find
+  // the graphics file in the directory where the DVI file resides
+  if (base.isLocalFile()) {
+    QString path = base.path();       // -> "/bar/foo.dvi"
+    QFileInfo fi1(path);
+    QFileInfo fi2(fi1.dir(),filename);
+    if (fi2.exists())
+      return fi2.absFilePath();
   }
+  
+  // Otherwise, use kpsewhich to find the eps file.
+  QString EPSfilename;
+  KProcIO proc;
+  proc << "kpsewhich" << filename;
+  proc.start(KProcess::Block);
+  proc.readln(EPSfilename);
 
-  QFileInfo fi1(dvi->filename);
-  QFileInfo fi2(fi1.dir(),EPSfilename);
-  if (fi2.exists())
-    EPSfilename = fi2.absFilePath();
-  else {
-    // Use kpsewhich to find the eps file.
-    KProcIO proc;
-    proc << "kpsewhich" << EPSfilename;
-    proc.start(KProcess::Block);
-    proc.readln(EPSfilename);
-    EPSfilename = EPSfilename.stripWhiteSpace();
-  }
-
-  return EPSfilename;
+  return EPSfilename.stripWhiteSpace();
 }
 
 #include "psgs.moc"
