@@ -1,6 +1,6 @@
    /*
 
-    $Id: kfax.cpp 465369 2005-09-29 14:33:08Z mueller $
+    $Id: kfax.cpp 546368 2006-05-29 20:51:20Z deller $
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -344,7 +344,7 @@ void TopLevel::updateZoomActions()
 {
   actSize->setEnabled( Image && oz > 0 );
   actZoomIn->setEnabled( Image && oz > 0 );
-  actZoomOut->setEnabled( Image && oz < MAXZOOM && Image->width >= 256 );
+  actZoomOut->setEnabled( Image && oz < MAXZOOM-1 && Image->width >= 256 );
 }
 
 bool TopLevel::queryClose()
@@ -434,29 +434,45 @@ void TopLevel::faxSaveAs()
   actRecent->addURL( fileURL );
 }
 
+
+static void freeImages()
+{
+  int i;
+  for (i = 1; i < MAXZOOM; i++) {
+    if (Images[i])
+	FreeImage(Images[i]);
+    Images[i] = NULL;
+  }
+}
+
+static XImage *generateZoomImages(int maxzoom)
+{
+  int i;
+  for (i = 1; i < MAXZOOM; i++){
+    if (!Images[i-1])
+	continue;
+    Image = Images[i] = ZoomImage(Images[i-1]);
+    if(Image == NULL){// out of memory
+      Image = Images[i -1];
+      break;
+    }
+  }
+
+  i = maxzoom;
+  while (!Images[i])
+	i--;
+  return Images[i];
+}
+
+
 void TopLevel::zoom( int factor )
 {
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
-  Image = Images[ factor ];
   Resize = Refresh = 1;
 
-  int i;
-
-  if (Image == NULL) {
-    for (i = factor; i && (Images[i] == NULL); i--)
-      ;
-    for (; i != factor; i++){
-      Images[i+1] = ZoomImage(Images[i]);
-      Image = Images[i+1];
-
-      if(Images[i+1] == NULL){ // out of memory
-	Image = Images[i];
-	break;
-      }
-    }
-  }
+  Image = generateZoomImages(factor);
 
   PaneWidth = Image->width;
   PaneHeight = Image->height;
@@ -907,8 +923,7 @@ void SetupDisplay(){
   XDefineCursor(qtdisplay, Win, ReadyCursor);
   XFlush(qtdisplay);
 
-  for (oz = 0; oz < MAXZOOM; oz++)
-    Images[oz] = NULL;
+  memset(Images, 0, sizeof(Images));
 
   // Start at half the Size
   oz = 1;
@@ -1129,38 +1144,22 @@ void TopLevel::rotatePage()
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
-  XImage *newrotimage = NULL;
-
   XDefineCursor(qtdisplay, Win, WorkCursor);
   XFlush(qtdisplay);
 
-  newrotimage = RotImage(Images[0]);
+  XImage *newrotimage = RotImage(Images[0]);
+
+  XDefineCursor(qtdisplay, Win, ReadyCursor);
 
   if(newrotimage == NULL){ // out of memory
-    XDefineCursor(qtdisplay, Win, ReadyCursor);
     return;
   }
 
-  thispage->extra = Image = newrotimage;
+  thispage->extra = Images[0] = newrotimage;
   thispage->orient ^= TURN_L;
 
-  int i;
-  for (i = 1; Images[i]; i++) {
-    FreeImage(Images[i]);
-    Images[i] = NULL;
-  }
-
-  Images[0] = Image;
-
-  for (i = 1; i <= oz; i++){
-
-    Images[i] = ZoomImage(Images[i-1]);
-    Image = Images[i];
-    if(Images[i] == NULL){// out of memory
-      Image = Images[i -1];
-      break;
-    }
-  }
+  freeImages();
+  Image = generateZoomImages(oz);
 
   { int t = xpos ; xpos= ypos; ypos= t; }
 
@@ -1174,31 +1173,22 @@ void TopLevel::flipPage()
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
-  XImage *newflipimage = NULL;
-
   XDefineCursor(qtdisplay, Win, WorkCursor);
   XFlush(qtdisplay);
 
-  newflipimage = FlipImage(Images[0]);
+  XImage *newflipimage = FlipImage(Images[0]);
+
+  XDefineCursor(qtdisplay, Win, ReadyCursor);
 
   if(newflipimage == NULL){ // out of memory
-    XDefineCursor(qtdisplay, Win, ReadyCursor);
     return;
   }
 
   thispage->extra = Images[0] = newflipimage;
   thispage->orient ^= TURN_U;
 
-  int i;
-  for (i = 1; Images[i]; i++) {
-    FreeImage(Images[i]);
-    Images[i] = ZoomImage(Images[i-1]);
-    if(Images[i]== NULL){// out of memory
-      break;
-    }
-  }
-
-  Image = Images[QMIN(i-1,oz)];
+  freeImages();
+  Image = generateZoomImages(oz);
 
   Refresh = Resize = 1;
   putImage();
@@ -1209,29 +1199,21 @@ void TopLevel::mirrorPage()
   if(!thispage || !Image || !faxqtwin || !display_is_setup)
     return;
 
-  XImage *newmirror = NULL;
-
   XDefineCursor(qtdisplay, Win, WorkCursor);
   XFlush(qtdisplay);
 
-  newmirror = MirrorImage(Images[0]);
+  XImage *newmirror = MirrorImage(Images[0]);
+
+  XDefineCursor(qtdisplay, Win, ReadyCursor);
 
   if(newmirror == NULL){ // out of memory
-    XDefineCursor(qtdisplay, Win, ReadyCursor);
     return;
   }
   thispage->extra = Images[0] = newmirror;
-
   thispage->orient ^= TURN_M;
 
-  int i;
-  for (i = 1; Images[i]; i++) {
-    FreeImage(Images[i]);
-    Images[i] = ZoomImage(Images[i-1]);
-    if (Images[i] == NULL) // out of memory
-      break;
-  }
-  Image = Images[QMIN(oz,i-1)];
+  freeImages();
+  Image = generateZoomImages(oz);
 
   Refresh = Resize = 1;
   putImage();
@@ -1296,6 +1278,7 @@ void TopLevel::firstPage()
 
   updateGoActions();
 }
+
 void TopLevel::nextPage()
 {
   if(!thispage)
@@ -1332,25 +1315,16 @@ void TopLevel::prevPage()
 
 void TopLevel::newPage(){
 
-
   if(!display_is_setup)
     SetupDisplay();
 
-
   XDefineCursor(qtdisplay, Win, WorkCursor);
   XFlush(qtdisplay);
 
-
-  int i;
-
-  for (i = 1; Images[i]; i++) {
-    FreeImage(Images[i]);
-    Images[i] = NULL;
-  }
+  freeImages();
 
   int k = -1;
 
-
   if(!thispage) {
     XDefineCursor(qtdisplay, Win, ReadyCursor);
     return;
@@ -1383,15 +1357,8 @@ void TopLevel::newPage(){
 
   setCaption(thispage->name);
 
-  for (i = 1; i <= oz; i++){
-    Images[i] = ZoomImage(Images[i-1]);
-    Image = Images[i];
-    if (Images[i] == NULL){ // out of memory
-      Image = Images[i-1];
-      break;
-    }
-  }
-
+  Image = generateZoomImages(oz);
+  
   PaneWidth = Image->width;
   PaneHeight = Image->height;
   Refresh = 1;
@@ -1425,16 +1392,13 @@ void TopLevel::FreeFax()
   if(display_is_setup)
     XClearWindow(qtdisplay, Win);
 
-  for (int i = 1; Images[i]; i++) {
-	  FreeImage(Images[i]);
-	  Images[i] = NULL;
-  }
+  freeImages();
 
   pagenode *pn;
-
   for (pn = firstpage; pn; pn = pn->next){
     if(Pimage(pn)){
        FreeImage(Pimage(pn));
+       pn->extra = NULL;
     }
   }
 
