@@ -14,27 +14,16 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */  
 
 #ifndef __KCOLORGRID_H__
 #define __KCOLORGRID_H__
 
-#include <qcursor.h>
-#include <qpointarray.h>
-#include <qdrawutil.h>
-#include <qbrush.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qbitmap.h>
-#include <qbuffer.h>
-#include <qclipboard.h>
-#include <qscrollbar.h>
-#include <qfileinfo.h>
-
-#include <kfiledialog.h> 
-#include <kapplication.h>
+#include <qwidget.h>
+#include <qsize.h>
+#include <qrect.h>
 
 #include "utils.h"
 
@@ -112,9 +101,4 @@ protected:
   KColorArray gridcolors, numcolors;
 };
 
-
-
 #endif //__KCOLORGRID_H__
-
-
-
