@@ -1,4 +1,4 @@
-#include <indexer.h>
+#include "indexer.h"
 #include <kmrml_config.h>
 #include "indextest.moc"
 
@@ -15,13 +15,13 @@ IndexTest::IndexTest()
     connect( indexer, SIGNAL( finished( bool )), SLOT( slotFinished( bool )));
     connect( indexer, SIGNAL( progress( int, const QString& )),
              SLOT( slotProgress( int, const QString& )));
-    
+
     indexer->startIndexing( "/home/gis/testcoll" );
 }
 
 IndexTest::~IndexTest()
 {
-    
+
 }
 
 void IndexTest::slotFinished( bool success )
@@ -38,6 +38,6 @@ int main( int argc, char **argv )
 {
     KApplication app( argc, argv, "indextest" );
     IndexTest *test = new IndexTest();
-    
+
     return app.exec();
 }
