@@ -5,7 +5,7 @@
     copyright            : (C) 1999 by Klaas Freitag
     email                : freitag@suse.de
 
-    $Id: kookaview.cpp,v 1.75 2004/11/20 17:27:51 deller Exp $
+    $Id: kookaview.cpp 532710 2006-04-22 16:07:13Z pfeiffer $
  ***************************************************************************/
 
 /***************************************************************************
@@ -865,10 +865,18 @@ void KookaView::slShowThumbnails(KFileTreeViewItem *dirKfi, bool forceRedraw )
    {
       /* do on the current visible dir */
       KFileTreeViewItem *kftvi = packager->currentKFileTreeViewItem();
-      if( ! kftvi->isDir())
-	 kftvi = static_cast<KFileTreeViewItem*>(static_cast<QListViewItem*>(kftvi)->parent());
-      if( kftvi )
+      if ( !kftvi )
       {
+          return;
+      }
+      
+      if( kftvi->isDir())
+      {
+          dirKfi = kftvi;
+      }
+      else
+      {
+	 kftvi = static_cast<KFileTreeViewItem*>(static_cast<QListViewItem*>(kftvi)->parent());
 	 dirKfi = kftvi;
 	 forceRedraw = true;
 	 packager->setSelected( static_cast<QListViewItem*>(dirKfi), true );
