@@ -44,6 +44,7 @@ class KPDFDocumentPrivate
     public:
         // find descriptors, mapped by ID (we handle multiple searches)
         QMap< int, RunningSearch * > searches;
+        int m_lastSearchID;
 
         // needed because for remote documents docFileName is a local file and
         // we want the remote url when the document refers to relativeNames
@@ -111,6 +112,7 @@ KPDFDocument::KPDFDocument()
     d->allocatedPixmapsTotalMemory = 0;
     d->memCheckTimer = 0;
     d->saveBookmarksTimer = 0;
+    d->m_lastSearchID = -1;
     KImageIO::registerFormats();
     QStringList list = QImage::inputFormatList();
     QStringList::Iterator it = list.begin();
@@ -627,6 +629,11 @@ bool KPDFDocument::searchText( int searchID, const QString & text, bool fromStar
         search->continueOnPage = -1;
         d->searches[ searchID ] = search;
     }
+    if (d->m_lastSearchID != searchID)
+    {
+        resetSearch(d->m_lastSearchID);
+    }
+    d->m_lastSearchID = searchID;
     RunningSearch * s = d->searches[ searchID ];
 
     // update search stucture
@@ -903,6 +910,10 @@ void KPDFDocument::resetSearch( int searchID )
     delete s;
 }
 
+bool KPDFDocument::continueLastSearch()
+{
+    return continueSearch( d->m_lastSearchID );
+}
 
 
 void KPDFDocument::toggleBookmark( int n )
@@ -1059,12 +1070,8 @@ void KPDFDocument::processLink( const KPDFLink * link )
                     return;
                 }
 
-                // get service for web browsing
-                KService::Ptr ptr = KServiceTypeProfile::preferredService("text/html", "Application");
-                KURL::List lst;
-                // append 'url' parameter to the service and run it
-                lst.append( url );
-                KRun::run( *ptr, lst );
+                // Albert: this is not a leak!
+                new KRun(url);
             }
             } break;
 
