@@ -213,13 +213,13 @@ Part::Part(QWidget *parentWidget, const char *widgetName,
 
 	m_prevPage = KStdAction::prior(this, SLOT(slotPreviousPage()), ac, "previous_page");
 	m_prevPage->setWhatsThis( i18n( "Moves to the previous page of the document" ) );
-	m_prevPage->setShortcut( "Backspace" );
+	m_prevPage->setShortcut( 0 );
 	// dirty way to activate prev page when pressing miniBar's button
 	connect( m_miniBar, SIGNAL( prevPage() ), m_prevPage, SLOT( activate() ) );
 
 	m_nextPage = KStdAction::next(this, SLOT(slotNextPage()), ac, "next_page" );
 	m_nextPage->setWhatsThis( i18n( "Moves to the next page of the document" ) );
-	m_nextPage->setShortcut( "Space" );
+	m_nextPage->setShortcut( 0 );
 	// dirty way to activate next page when pressing miniBar's button
 	connect( m_miniBar, SIGNAL( nextPage() ), m_nextPage, SLOT( activate() ) );
 
@@ -586,8 +586,13 @@ void Part::enableTOC(bool enable)
 
 void Part::psTransformEnded()
 {
+	QString aux = m_file;
 	m_file = m_temporaryLocalFile;
 	openFile();
+	m_file = aux; // so watching works, we have to watch the ps file not the autogenerated pdf
+	m_watcher->removeFile(m_temporaryLocalFile);
+	if ( !m_watcher->contains(m_file) )
+		m_watcher->addFile(m_file);
 }
 
 void Part::cannotQuit()
@@ -676,6 +681,8 @@ void Part::slotFind()
 {
     KFindDialog dlg( widget() );
     dlg.setHasCursor( false );
+    if ( !m_searchHistory.empty() )
+        dlg.setFindHistory( m_searchHistory );
 #if KDE_IS_VERSION(3,3,90)
     dlg.setSupportsBackwardsFind( false );
     dlg.setSupportsWholeWordsFind( false );
@@ -683,6 +690,7 @@ void Part::slotFind()
 #endif
     if ( dlg.exec() == QDialog::Accepted )
     {
+        m_searchHistory = dlg.findHistory();
         m_searchStarted = true;
         m_document->resetSearch( PART_SEARCH_ID );
         m_document->searchText( PART_SEARCH_ID, dlg.pattern(), false, dlg.options() & KFindDialog::CaseSensitive,
@@ -692,9 +700,7 @@ void Part::slotFind()
 
 void Part::slotFindNext()
 {
-    if ( m_searchStarted )
-        m_document->continueSearch( PART_SEARCH_ID );
-    else
+    if (!m_document->continueLastSearch())
         slotFind();
 }
 
