@@ -21,7 +21,6 @@
 #endif
 
 #include <kparts/mainwindow.h>
-class KPopupMenu;
 
 namespace KPDF
 {
@@ -40,15 +39,15 @@ namespace KPDF
 
   public:
     /**
-     * Open an url 
-     */ 
-     Shell(const KURL &url); 
-
-     /**
      * Default Constructor
      */
     Shell();
 
+    /**
+     * Open an url
+     */
+    Shell(const KURL &url);
+
     /**
      * Default Destructor
      */
@@ -71,23 +70,25 @@ namespace KPDF
     void writeSettings();
     void setFullScreen( bool );
 
+  public slots:
+    void slotQuit();
+
   private slots:
     void fileOpen();
 
-    void slotQuit();
-
     void optionsConfigureToolbars();
     void applyNewToolbarConfig();
     void slotUpdateFullScreen();
     void slotShowMenubar();
 
-      void openURL( const KURL & url );
+    void openURL( const KURL & url );
     void delayedOpen();
 
   signals:
       void restoreDocument(const KURL &url, int page);
       void saveDocumentRestoreInfo(KConfig* config);
-
+     
+     
   private:
     void setupAccel();
     void setupActions();
