@@ -48,7 +48,7 @@ void PMBumpMapEdit::createTopWidgets( )
 {
    QLabel* lbl;
    QHBoxLayout* hl;
-   
+
    Base::createTopWidgets( );
 
    hl = new QHBoxLayout( topLayout( ) );
@@ -198,12 +198,12 @@ void PMBumpMapEdit::displayObject( PMObject* o )
       m_pOnceEdit->setEnabled( !readOnly );
       m_pUseIndexEdit->setChecked( m_pDisplayedObject->isUseIndexEnabled( ) );
       m_pUseIndexEdit->setEnabled( !readOnly );
-      m_pBumpSizeEdit->setValue( m_pDisplayedObject->isUseIndexEnabled( ) );
+      m_pBumpSizeEdit->setValue( m_pDisplayedObject->bumpSize( ) );
       m_pBumpSizeEdit->setReadOnly( readOnly );
 
       Base::displayObject( o );
    }
-    
+
 }
 
 void PMBumpMapEdit::saveContents( )
