@@ -122,6 +122,8 @@ public:
    /** */
    virtual void controlPointsChanged( PMControlPointList& list );
    /** */
+   virtual bool hasDisplayDetail( ) const { return true; }
+   /** */
    virtual void cleanUp( ) const;
 
 protected:
@@ -132,14 +134,18 @@ protected:
    /** */
    virtual PMViewStructure* defaultViewStructure( ) const;
    /** */
-   virtual int viewStructureParameterKey( ) const { return s_parameterKey; }
+   virtual int viewStructureParameterKey( ) const { return s_parameterKey + globalDetailKey(); }
 
 private:
+   /**
+    * Creates the lines for the view structure
+    */
+   static void createLines( PMLineArray& lines, int steps );
    /**
     * Creates the points for the view structure
     */
    static void createPoints( PMPointArray& points, const PMVector& end1,
-                             const PMVector& end2, double radius );
+                             const PMVector& end2, double radius, int steps );
 
    /**
     * IDs for @ref PMMementoData
