@@ -191,7 +191,7 @@ void PMDialogEditBase::displayObject( PMObject* o )
          hl->addWidget( m_pPreviewButton );
          connect( m_pPreviewButton, SIGNAL( clicked( ) ),
                   SLOT( slotTexturePreview( ) ) );
-         m_pOutputButton = new QPushButton( i18n( "Povray Output..." ), m_pTexturePreviewWidget );
+         m_pOutputButton = new QPushButton( i18n( "Povray Output" ), m_pTexturePreviewWidget );
          hl->addWidget( m_pOutputButton );
          connect( m_pOutputButton, SIGNAL( clicked( ) ),
                   SLOT( slotPovrayOutput( ) ) );
