@@ -36,13 +36,13 @@ PMErrorDialog::PMErrorDialog( const PMMessageList& messages, int errorFlags,
    QVBox* page = makeVBoxMainWidget( );
    QLabel* text = new QLabel( QString( "" ), ( QWidget* )page );
 
-
+   
    m_pTextView = new QTextEdit( ( QWidget* )page );
    m_pTextView->setReadOnly( true );
 
    m_messageDict.setAutoDelete( true );
    m_messages.setAutoDelete( true );
-
+   
    PMMessageList::ConstIterator it;
    for( it = messages.begin( ); it != messages.end( ); ++it )
       m_messages.append( new PMMessage( *it ) );
@@ -70,7 +70,7 @@ PMErrorDialog::PMErrorDialog( const PMMessageList& messages, int errorFlags,
          }
       }
    }
-
+   
    displayMessages( );
 
    if( errorFlags & PMEWarning )
@@ -82,20 +82,20 @@ PMErrorDialog::PMErrorDialog( const PMMessageList& messages, int errorFlags,
    }
    else
       text->setText( i18n( "There were errors:" ) );
-
+   
    setButtonOKText( KStdGuiItem::ok().text(),
                     i18n( "Proceed" ),
                     i18n( "When clicking <b>Proceed</b>, the program\n"
                           "will try to proceed with the current action." ) );
    setButtonCancelText( KStdGuiItem::cancel().text(),
-                        i18n( "Cancel" ),
+                        i18n( "&Cancel" ),
                         i18n( "When clicking <b>Cancel<b>, the program\n"
                               "will cancel the current action." ) );
-
+      
    if( errorFlags & PMEFatal )
       showButtonOK( false );
    else
-      new QLabel( QString( "Still try to proceed?" ), ( QWidget* )page );
+      new QLabel( i18n( "Still try to proceed?" ), ( QWidget* )page );
 
    resize( s_size );
 }
@@ -106,12 +106,12 @@ void PMErrorDialog::displayMessages( )
    QString text;
 
    text = "<qt>\n";
-
+   
    for( ; pit.current( ); ++pit )
       text += "<p>" + pit.current( )->text( ) + "</p>\n";
 
    text += "</qt>";
-
+   
    m_pTextView->setText( text );
 }
 
