@@ -33,7 +33,7 @@ extern "C"
    }
 }
 
-static const char* description = I18N_NOOP( "Modeler for POV-Ray Scenes" );
+static const char description[] = I18N_NOOP( "Modeler for POV-Ray Scenes" );
 
 KInstance* PMFactory::s_instance = 0L;
 KAboutData* PMFactory::s_aboutData = 0L;
