@@ -24,6 +24,7 @@
 #include "pmmemento.h"
 #include "pmviewstructure.h"
 #include "pmenumproperty.h"
+#include "pmdefaults.h"
 
 #include <klocale.h>
 
@@ -33,12 +34,15 @@ const QString c_defaultFileName = QString( "" );
 const bool c_defaultHierarchy = true;
 const bool c_defaultSmooth = false;
 const double c_defaultWaterLevel = 0.0;
-const int c_defaultDisplayDetail = 8;
 
-PMDefinePropertyClass( PMHeightField, PMProperty );
+PMDefinePropertyClass( PMHeightField, PMHeightFieldProperty );
 PMDefineEnumPropertyClass( PMHeightField, PMHeightField::HeightFieldType,
                            PMHeightFieldTypeProperty );
 
+
+int PMHeightField::s_variance = c_defaultHeightFieldVariance;
+int PMHeightField::s_parameterKey = 0;
+
 PMViewStructure* PMHeightField::s_pDefaultViewStructure = 0;
 PMMetaObject* PMHeightField::s_pMetaObject = 0;
 
@@ -55,8 +59,8 @@ PMHeightField::PMHeightField( PMPart* part )
    m_hierarchy = c_defaultHierarchy;
    m_smooth = c_defaultSmooth;
    m_waterLevel = c_defaultWaterLevel;
-   m_displayDetail = c_defaultDisplayDetail;
 
+   m_modMap = true;
    m_pROAM = 0;
 }
 
@@ -68,13 +72,14 @@ PMHeightField::PMHeightField( const PMHeightField& f )
    m_hierarchy = f.m_hierarchy;
    m_smooth = f.m_smooth;
    m_waterLevel = f.m_waterLevel;
-   m_displayDetail = f.m_displayDetail;
+
+   m_modMap = true;
+   m_pROAM = 0;
 }
 
 PMHeightField::~PMHeightField( )
 {
-   if ( m_pROAM )
-      delete m_pROAM;
+   delete m_pROAM;
 }
 
 QString PMHeightField::description( ) const
@@ -89,7 +94,6 @@ void PMHeightField::serialize( QDomElement& e, QDomDocument& doc ) const
    e.setAttribute( "hierarchy", m_hierarchy );
    e.setAttribute( "smooth", m_smooth );
    e.setAttribute( "water_level", m_waterLevel );
-   e.setAttribute( "display_detail", m_displayDetail );
    Base::serialize( e, doc );
 }
 
@@ -100,7 +104,6 @@ void PMHeightField::readAttributes( const PMXMLHelper& h )
    m_hierarchy = h.boolAttribute( "hierarchy", c_defaultHierarchy );
    m_smooth = h.boolAttribute( "smooth", c_defaultSmooth );
    m_waterLevel = h.doubleAttribute( "water_level", c_defaultWaterLevel );
-   m_displayDetail = h.intAttribute( "display_detail", c_defaultDisplayDetail );
    Base::readAttributes( h );
 }
 
@@ -111,15 +114,13 @@ PMMetaObject* PMHeightField::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "HeightField", Base::metaObject( ),
                                         createNewHeightField );
       s_pMetaObject->addProperty(
-         new PMProperty( "fileName", &PMHeightField::setFileName, &PMHeightField::fileName ) );
+         new PMHeightFieldProperty( "fileName", &PMHeightField::setFileName, &PMHeightField::fileName ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "hierarchy", &PMHeightField::setHierarchy, &PMHeightField::hierarchy ) );
+         new PMHeightFieldProperty( "hierarchy", &PMHeightField::setHierarchy, &PMHeightField::hierarchy ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "smooth", &PMHeightField::setSmooth, &PMHeightField::smooth ) );
+         new PMHeightFieldProperty( "smooth", &PMHeightField::setSmooth, &PMHeightField::smooth ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "waterLevel", &PMHeightField::setWaterLevel, &PMHeightField::waterLevel ) );
-      s_pMetaObject->addProperty(
-         new PMProperty( "displayDetail", &PMHeightField::setDisplayDetail, &PMHeightField::displayDetail ) );
+         new PMHeightFieldProperty( "waterLevel", &PMHeightField::setWaterLevel, &PMHeightField::waterLevel ) );
       PMHeightFieldTypeProperty* p =
          new PMHeightFieldTypeProperty( "heightFieldType", &PMHeightField::setHeightFieldType,
                                         &PMHeightField::heightFieldType );
@@ -152,25 +153,8 @@ void PMHeightField::setFileName( const QString& f )
       if( m_pMemento )
          m_pMemento->addData( s_pMetaObject, PMFileNameID, m_fileName );
       m_fileName = f;
-
-      if ( m_pROAM )
-      {
-         delete m_pROAM;
-         m_pROAM = 0;
-         setViewStructureChanged( );
-      }
-      if ( !m_fileName.isEmpty( ) && m_displayDetail > 0 )
-      {
-         m_pROAM = new PMHeightFieldROAM( m_fileName,
-                                          m_waterLevel,
-                                          m_displayDetail );
-         if ( m_pROAM->isFailed( ) )
-         {
-            delete m_pROAM;
-            m_pROAM = 0;
-         }
-         setViewStructureChanged( );
-      }
+      m_modMap = true;
+      setViewStructureChanged( );
    }
 }
 
@@ -212,75 +196,10 @@ void PMHeightField::setWaterLevel( double wl )
       if( m_pMemento )
          m_pMemento->addData( s_pMetaObject, PMWaterLevelID, m_waterLevel );
       m_waterLevel = wl;
-
-      if ( m_pROAM )
-      {
-            delete m_pROAM;
-            m_pROAM = new PMHeightFieldROAM( m_fileName,
-                                             m_waterLevel,
-                                             m_displayDetail );
-            if ( m_pROAM->isFailed( ) )
-            {
-               delete m_pROAM;
-               m_pROAM = 0;
-            }
-      }
-
       setViewStructureChanged( );
    }
 }
 
-void PMHeightField::setDisplayDetail( int dd )
-{
-   if( dd < 0 )
-   {
-      kdError( PMArea ) << "Display Detail < 0 in PMHeightField::setDisplayDetail\n";
-      dd = 0;
-   }
-   if(dd > 256 )
-   {
-      kdError( PMArea ) << "Display Detail > 256 in PMHeightField::setDisplayDetail\n";
-      dd = 256;
-   }
-
-   if( dd != m_displayDetail )
-   {
-      if( m_pMemento )
-         m_pMemento->addData( s_pMetaObject, PMDisplayDetailID, m_displayDetail );
-      m_displayDetail = dd;
-
-      if ( !m_fileName.isEmpty( ) && m_displayDetail > 0 )
-      {
-         if ( !m_pROAM )
-         {
-            m_pROAM = new PMHeightFieldROAM( m_fileName,
-                                             m_waterLevel,
-                                             m_displayDetail );
-            if ( m_pROAM->isFailed( ) )
-            {
-               delete m_pROAM;
-               m_pROAM = 0;
-            }
-            else setViewStructureChanged( );
-         }
-         else
-         {
-            m_pROAM->setLOD( m_displayDetail );
-            setViewStructureChanged( );
-         }
-      }
-      else
-      {
-         if ( m_pROAM )
-         {
-            delete m_pROAM;
-            m_pROAM = 0;
-            setViewStructureChanged( );
-         }
-      }
-   }
-}
-
 PMDialogEditBase* PMHeightField::editWidget( QWidget* parent ) const
 {
    return new PMHeightFieldEdit( parent );
@@ -313,9 +232,6 @@ void PMHeightField::restoreMemento( PMMemento* s )
             case PMWaterLevelID:
                m_waterLevel = data->doubleData( );
                break;
-            case PMDisplayDetailID:
-               m_displayDetail = data->intData( );
-               break;
             default:
                kdError( PMArea ) << "Wrong ID in PMHeightField::restoreMemento\n";
                break;
@@ -328,53 +244,63 @@ void PMHeightField::restoreMemento( PMMemento* s )
 
 bool PMHeightField::isDefault( )
 {
-   return ( m_waterLevel == c_defaultWaterLevel &&
-            ( m_displayDetail == 0 || m_fileName.isEmpty( ) ) );
+   return ( m_waterLevel == c_defaultWaterLevel && m_fileName.isEmpty( ) );
 }
 
 void PMHeightField::createViewStructure( )
 {
-   if ( !m_fileName.isEmpty( ) && m_displayDetail > 0 )
+   int detail = 65200 - ( ( s_variance * 163 ) * ( displayDetail( ) * displayDetail( ) ) );
+   if ( m_modMap )
    {
-      if ( !m_pROAM )
+      m_modMap = false;
+
+      if ( m_pROAM )
       {
-         m_pROAM = new PMHeightFieldROAM( m_fileName,
-                                          m_waterLevel,
-                                          m_displayDetail );
+         delete m_pROAM;
+         m_pROAM = 0;
+      }
+
+      if ( !m_fileName.isEmpty( ) )
+      {
+         m_pROAM = new PMHeightFieldROAM( m_fileName );
+
          if ( m_pROAM->isFailed( ) )
          {
             delete m_pROAM;
             m_pROAM = 0;
-            setDisplayDetail( 0 );
-            createViewStructure( );
-            return;
          }
       }
+   }
+
+   if ( m_pROAM )
+   {
+      m_pROAM->setDisplayDetail( detail );
+      m_pROAM->setWaterLevel( m_waterLevel );
+      m_pROAM->updateModel( );
       roamViewStructure( );
+      return;
+   }
+
+   if ( !m_pViewStructure )
+   {
+      m_pViewStructure = new PMViewStructure( defaultViewStructure( ) );
+      m_pViewStructure->points( ).detach( );
+      m_pViewStructure->lines( ).detach( );
    }
    else
    {
-      if( !m_pViewStructure )
-      {
-         m_pViewStructure = new PMViewStructure( defaultViewStructure( ) );
-         m_pViewStructure->points( ).detach( );
-         m_pViewStructure->lines( ).detach( );
-      }
-      else
-      {
-         m_pViewStructure->points( ).resize(
+      m_pViewStructure->points( ).resize(
             defaultViewStructure( )->points( ).size( ) );
-         m_pViewStructure->lines( ).resize(
+      m_pViewStructure->lines( ).resize(
             defaultViewStructure( )->lines( ).size( ) );
-      }
-
-      PMPointArray& points = m_pViewStructure->points( );
-
-      points[4][1] = m_waterLevel;
-      points[5][1] = m_waterLevel;
-      points[6][1] = m_waterLevel;
-      points[7][1] = m_waterLevel;
    }
+
+   PMPointArray& points = m_pViewStructure->points( );
+
+   points[4][1] = m_waterLevel;
+   points[5][1] = m_waterLevel;
+   points[6][1] = m_waterLevel;
+   points[7][1] = m_waterLevel;
 }
 
 void PMHeightField::roamViewStructure( )
@@ -386,8 +312,15 @@ void PMHeightField::roamViewStructure( )
       m_pViewStructure->lines( ).detach( );
    }
 
-   m_pViewStructure->points( ).resize( m_pROAM->usedPoints( ) + 12 );
-   m_pViewStructure->lines( ).resize( m_pROAM->numLines( ) + 20 );
+   int x, z, i, pts;
+   int size = m_pROAM->size( );
+   int currentLine = defaultViewStructure( )->lines( ).size( );
+   int defPointsNum = defaultViewStructure( )->points( ).size( );
+   double dx, dy, dz;
+   double sizeM1 = size - 1.0;
+
+   m_pViewStructure->points( ).resize( m_pROAM->usedPoints( ) + defPointsNum );
+   m_pViewStructure->lines( ).resize( m_pROAM->numLines( ) + currentLine );
 
    PMPointArray& points = m_pViewStructure->points( );
    PMLineArray& lines = m_pViewStructure->lines( );
@@ -397,28 +330,22 @@ void PMHeightField::roamViewStructure( )
    points[6][1] = m_waterLevel;
    points[7][1] = m_waterLevel;
 
-   int x, z, i, pts, size;
-   int currentLine = 20;
-   double doublex, doubley, doublez, sizeM1;
-
-   size = m_pROAM->size( );
-   sizeM1 = size - 1.0;
    for ( x = 0; x < size; ++x )
    {
-      doublex = x / sizeM1;
-      for ( z = 0; z < size ; ++z )
+      dx = x / sizeM1;
+      for ( z = 0; z < size; ++z )
       {
-         doublez = z / sizeM1;
+         dz = z / sizeM1;
          if ( m_pROAM->usedPoint( x, z ) )
          {
-            pts = m_pROAM->posPoint( x, z ) + 12;
-            doubley = m_pROAM->height( x, z ) / 65535.0;
-            points[ pts ] = PMPoint( doublex, doubley, doublez );
+            pts = m_pROAM->posPoint( x, z ) + defPointsNum;
+            dy = m_pROAM->height( x, z, true ) / 65535.0;
+            points[ pts ] = PMPoint( dx, dy, dz );
 
-            for ( i = 0; m_pROAM->lineExist( x, z, i ) && i < 8 ; ++i )
+            for ( i = 0; m_pROAM->lineExist( x, z, i ) && i < 8; ++i )
             {
                lines[ currentLine++ ] =
-                     PMLine( pts, m_pROAM->endPoint( x, z, i ) + 12 );
+                  PMLine( pts, m_pROAM->endPoint( x, z, i ) + defPointsNum );
             }
          }
       }
@@ -429,7 +356,7 @@ PMViewStructure* PMHeightField::defaultViewStructure( ) const
 {
    if( !s_pDefaultViewStructure )
    {
-      s_pDefaultViewStructure = new PMViewStructure( 12, 20 );
+      s_pDefaultViewStructure = new PMViewStructure( 12, 16 );
       PMPointArray& points = s_pDefaultViewStructure->points( );
       PMLineArray& lines = s_pDefaultViewStructure->lines( );
 
@@ -451,25 +378,20 @@ PMViewStructure* PMHeightField::defaultViewStructure( ) const
       lines[ 2] = PMLine( 2, 3 );
       lines[ 3] = PMLine( 0, 3 );
 
-      lines[ 4] = PMLine( 0, 4 );
-      lines[ 5] = PMLine( 1, 5 );
-      lines[ 6] = PMLine( 2, 6 );
-      lines[ 7] = PMLine( 3, 7 );
+      lines[ 4] = PMLine( 0, 8 );
+      lines[ 5] = PMLine( 1, 9 );
+      lines[ 6] = PMLine( 2, 10 );
+      lines[ 7] = PMLine( 3, 11 );
 
       lines[ 8] = PMLine( 4, 5 );
       lines[ 9] = PMLine( 5, 6 );
       lines[10] = PMLine( 6, 7 );
       lines[11] = PMLine( 4, 7 );
 
-      lines[12] = PMLine( 4, 8 );
-      lines[13] = PMLine( 5, 9 );
-      lines[14] = PMLine( 6, 10 );
-      lines[15] = PMLine( 7, 11 );
-
-      lines[16] = PMLine( 8, 9 );
-      lines[17] = PMLine( 9, 10 );
-      lines[18] = PMLine( 10, 11 );
-      lines[19] = PMLine( 8, 11 );
+      lines[12] = PMLine( 8, 9 );
+      lines[13] = PMLine( 9, 10 );
+      lines[14] = PMLine( 10, 11 );
+      lines[15] = PMLine( 8, 11 );
    }
    return s_pDefaultViewStructure;
 }
@@ -504,7 +426,7 @@ QString PMHeightField::typeToString( PMHeightField::HeightFieldType t )
    return s;
 }
 
-PMHeightField::HeightFieldType PMHeightField::stringToType( QString str )
+PMHeightField::HeightFieldType PMHeightField::stringToType( const QString &str )
 {
    HeightFieldType t = HFgif;
    if( str == "gif" )
@@ -524,6 +446,15 @@ PMHeightField::HeightFieldType PMHeightField::stringToType( QString str )
    return t;
 }
 
+void PMHeightField::setVariance( int v )
+{
+   if( v < 52 && v > 0 )
+      s_variance = v;
+   else
+      kdDebug( PMArea ) << "PMHeightField::setVariance: V must be less than 52 & greater than 0\n";
+   s_parameterKey++;
+}
+
 void PMHeightField::cleanUp( ) const
 {
    if( s_pDefaultViewStructure )
