@@ -23,9 +23,6 @@
 #include "pmpalettevalueedit.h"
 #include "pmvector.h"
 
-#include <kdebug.h>
-#include "pmglobals.h"
-
 #include <qwidget.h>
 #include <qlayout.h>
 #include <qcombobox.h>
@@ -143,7 +140,7 @@ void PMImageMapEdit::displayObject( PMObject* o )
 {
    bool readOnly;
 
-   if( o->isA( PMTImageMap ) )
+   if( o->isA( "ImageMap" ) )
    {
       m_pDisplayedObject = ( PMImageMap* ) o;
       readOnly = m_pDisplayedObject->isReadOnly( );
@@ -480,7 +477,7 @@ void PMImageMapEdit::slotImageFileBrowseClicked( )
 {
    QString str = KFileDialog::getOpenFileName( QString::null, QString::null );
 
-   if( str != "" && str != QString::null )
+   if( !str.isEmpty() )
    {
       m_pImageFileNameEdit->setText( str );
       emit dataChanged( );
