@@ -28,7 +28,7 @@
 
 #include <klocale.h>
 
-PMDefinePropertyClass( PMTextureBase, PMProperty );
+PMDefinePropertyClass( PMTextureBase, PMTextureBaseProperty );
 
 PMMetaObject* PMTextureBase::s_pMetaObject = 0;
 
@@ -55,10 +55,10 @@ PMMetaObject* PMTextureBase::metaObject( ) const
    {
       s_pMetaObject = new PMMetaObject( "TextureBase", Base::metaObject( ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "linkedObject", &PMTextureBase::setLinkedObjectProperty,
+         new PMTextureBaseProperty( "linkedObject", &PMTextureBase::setLinkedObjectProperty,
                          &PMTextureBase::linkedObjectProperty ) );
       s_pMetaObject->addProperty(
-         new PMProperty( "hasLinkedObject", 0, &PMTextureBase::hasLinkedObject ) );
+         new PMTextureBaseProperty( "hasLinkedObject", 0, &PMTextureBase::hasLinkedObject ) );
    }
    return s_pMetaObject;
 }
