@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -60,6 +60,7 @@ void SVGZoomAndPanImpl::parseZoomAndPan(const DOM::DOMString &attr)
 // Ecma stuff
 
 /*
+@namespace KSVG
 @begin SVGZoomAndPanImpl::s_hashTable 2
  zoomAndPan		SVGZoomAndPanImpl::ZoomAndPan		DontDelete
 @end
@@ -90,6 +91,7 @@ void SVGZoomAndPanImpl::putValueProperty(KJS::ExecState *exec, int token, const
 }
 
 /*
+@namespace KSVG
 @begin SVGZoomAndPanImplConstructor::s_hashTable 5
  SVG_ZOOMANDPAN_UNKNOWN      KSVG::SVG_ZOOMANDPAN_UNKNOWN     DontDelete|ReadOnly
  SVG_ZOOMANDPAN_DISABLE      KSVG::SVG_ZOOMANDPAN_DISABLE     DontDelete|ReadOnly
