@@ -43,20 +43,20 @@ namespace T2P
 		virtual void closePath(Glyph *glyph) = 0;
 
 		// FreeType glyph tracing functions
-		void setMoveto(int (funcPtr)(FT_Vector *, void *));
-		void setLineto(int (funcPtr)(FT_Vector *, void *));
-		void setConicBezier(int (funcPtr)(FT_Vector *, FT_Vector *, void *));
-		void setCubicBezier(int (funcPtr)(FT_Vector *, FT_Vector *, FT_Vector *, void *));
+		void setMoveto(FT_Outline_MoveToFunc funcPtr);
+		void setLineto(FT_Outline_LineToFunc funcPtr);
+		void setConicBezier(FT_Outline_ConicToFunc funcPtr);
+		void setCubicBezier(FT_Outline_CubicToFunc funcPtr);
 
 		FT_Outline_Funcs *outlineFuncs();
 
 	private:
 		FT_Outline_Funcs *m_outlineMethods;
 
-		int (*m_moveTo)(FT_Vector *, void *);
-		int (*m_lineTo)(FT_Vector *, void *);
-		int (*m_conicBezier)(FT_Vector *, FT_Vector *, void *);
-		int (*m_cubicBezier)(FT_Vector *, FT_Vector *, FT_Vector *, void *);
+		FT_Outline_MoveToFunc m_moveTo;
+		FT_Outline_LineToFunc m_lineTo;
+		FT_Outline_ConicToFunc m_conicBezier;
+		FT_Outline_CubicToFunc m_cubicBezier;
 	};
 }
 
