@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998-2003 Carsten Pfeiffer <pfeiffer@kde.org>
+   Copyright (C) 1998-2006 Carsten Pfeiffer <pfeiffer@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef KUICKSHOW_H
@@ -45,6 +45,8 @@ class AboutWidget;
 class KURL;
 class KURLComboBox;
 
+class KuickFile;
+
 class DelayedRepeatEvent
 {
 public:
@@ -52,18 +54,28 @@ public:
         viewer = view;
         event  = ev;
     }
-    DelayedRepeatEvent( ImageWindow *view, int step ) {
-        viewer = view;
-        steps  = step;
-        event  = 0L;
+    DelayedRepeatEvent( ImageWindow *view, int action, void *data ) {
+        this->viewer = view;
+        this->action = action;
+        this->data   = data;
+        this->event  = 0L;
     }
+
     ~DelayedRepeatEvent() {
         delete event;
     }
 
+    enum Action
+    {
+        DeleteCurrentFile,
+        TrashCurrentFile,
+        AdvanceViewer
+    };
+
     ImageWindow *viewer;
     QKeyEvent *event;
-    int steps;
+    int action;
+    void *data;
 };
 
 
@@ -82,10 +94,11 @@ public:
     // in the mainwindow's collection, but in the filewidget's.
     virtual KActionCollection* actionCollection() const;
 
-    
+
 protected:
     virtual void	readProperties( KConfig * );
     void 		initImlibParams( ImData *, ImlibInitParams * );
+    void                tryShowNextImage();
 
 private slots:
     void                toggleBrowser();
@@ -93,7 +106,7 @@ private slots:
     void 		slotPrint();
     void 		slotConfigApplied();
     void 		slotConfigClosed();
-    void 		messageCantLoadImage( const QString& );
+    void 		messageCantLoadImage( const KuickFile * file, const QString& message);
     void         	showImage(const KFileItem *, bool newWindow = false,
                                   bool fullscreen = false, bool moveToTopLeft = true );
     void 		showFileItem( ImageWindow *, const KFileItem * );
@@ -103,6 +116,7 @@ private slots:
     void		configuration();
     void	      	about();
     void 		startSlideShow();
+    void                pauseSlideShow();
     void 		nextSlide();
     void                nextSlide( KFileItem *item );
     void		viewerDeleted();
@@ -112,13 +126,19 @@ private slots:
 
     void 		slotShowInSameWindow();
     void 		slotShowInOtherWindow();
+    void                slotShowFullscreen();
 
     void		slotReplayEvent();
-    void                slotReplayAdvance();
     void                slotOpenURL();
     void		slotSetURL( const KURL& );
     void		slotURLComboReturnPressed();
 //     void                invalidateImages( const KFileItemList& items );
+    void		slotDeleteCurrentImage(ImageWindow *viewer);
+    void		slotTrashCurrentImage(ImageWindow *viewer);
+    void                slotDeleteCurrentImage();
+    void                slotTrashCurrentImage();
+
+    void                doReplay();
 
 private:
     void 		initGUI( const KURL& startDir );
@@ -128,7 +148,15 @@ private:
     void 		saveSettings();
     bool 		haveBrowser() const;
     void 		delayedRepeatEvent( ImageWindow *, QKeyEvent * );
+    void		abortDelayedEvent();
     void                deleteAllViewers();
+    void                redirectDeleteAndTrashActions(KActionCollection *coll);
+
+    void                delayAction(DelayedRepeatEvent *event);
+    void                replayAdvance(DelayedRepeatEvent *event);
+
+    void                performDeleteCurrentImage(QWidget *parent);
+    void                performTrashCurrentImage(QWidget *parent);
 
     uint 		viewItem, renameItem, deleteItem, printItem;
     uint                m_slideshowCycle;
@@ -142,7 +170,8 @@ private:
     KAccel 		*m_accel;
     DelayedRepeatEvent  *m_delayedRepeatItem;
     QTimer              *m_slideTimer;
-    KAction             *m_toggleBrowserAction;
+    bool                m_slideShowStopped;
+    KToggleAction       *m_toggleBrowserAction;
     QGuardedPtr<AboutWidget> aboutWidget;
 };
 
