@@ -1,3 +1,4 @@
+// -*- C++ -*-
 #ifndef history_h
 #define history_h
 
@@ -15,20 +16,27 @@ class HistoryItem
 {
  public:
   HistoryItem(Q_UINT32, Q_UINT32);
-  HistoryItem() {};
+  HistoryItem() {}
 
-  bool operator == (const HistoryItem& item);
+  bool operator== (const HistoryItem& item) const;
 
   Q_UINT32 page;
   Q_UINT32 ypos;
 };
 
+inline
+bool operator!=(const HistoryItem& lhs, const HistoryItem& rhs)
+{
+  return !(lhs == rhs);
+}
+
+
 class History : public QObject
 {
   Q_OBJECT
 
 public:
-  History(void);
+  History();
 
   void          add(Q_UINT32 page, Q_UINT32 ypos);
   void          clear();
