@@ -1,30 +1,32 @@
-#ifndef __KVIEWPART_H
-#define __KVIEWPART_H
+// -*- C++ -*-
+#ifndef KVIEWPART_H
+#define KVIEWPART_H
 
+#include "kviewpart_iface.h"
+#include "pageSize.h"
+#include "zoom.h"
 
-#include <kparts/part.h>
 #include <kparts/browserextension.h>
-#include <kdirwatch.h>
 #include <qtimer.h>
 
+class KAboutData;
 class KAboutDialog;
 class KAccel;
 class KAction;
+class KConfig;
+class KDirWatch;
+class KInstance;
+class KMultiPage;
+class KRadioAction;
 class KSelectAction;
 class KTempFile;
 class KToggleAction;
-class KViewPartExtension;
-class KInstance;
 class KURL;
-class QSize;
+class KViewPartExtension;
 class QHBoxLayout;
 class pageSizeDialog;
+class QSize;
 
-#include "kviewpart_iface.h"
-#include "kmultipage.h"
-#include "pageSize.h"
-#include "zoom.h"
-#include "zoomlimits.h"
 
 class KViewPart : public KViewPart_Iface
 {
@@ -39,9 +41,17 @@ public:
 
   bool isValid() { return multiPage; }
 
-  // Returns a description of the current page size, for use in the
-  // statusbar of the kviewshell that embeds this KViewPart.
-  QString pageSizeDescription(void);
+  /* This method calls closeURL(), but asks first ("The document was
+     modified. Do you really want to close?") if the document has been
+     modified after it has been loaded.  */
+  virtual bool closeURL_ask();
+
+  /* Returns a description of the current page size, for use in the
+     statusbar of the kviewshell that embeds this KViewPart. */
+  QString pageSizeDescription();
+
+  /** Returns a list of mimetypes supported by the installed KViewShell plugins. */
+  virtual QStringList supportedMimeTypes();
 
 signals:
   void zoomChanged(const QString &);
@@ -50,15 +60,18 @@ signals:
   void scrollbarStatusChanged(bool);
   void fileOpened();
 
+  void pluginChanged(KParts::Part*);
+
 public slots:
   void slotSetFullPage(bool fullpage);
 
   virtual void slotFileOpen();
   virtual bool closeURL();
-  virtual QStringList fileFormats();
+  virtual QStringList fileFormats() const;
   void setStatusBarTextFromMultiPage(const QString &);
+
   /** Calling this slot will cause the kmultipage to reload the file */
-  void reload(void);
+  void reload();
 
   void restoreDocument(const KURL &url, int page);
   void saveDocumentRestoreInfo(KConfig* config);
@@ -106,12 +119,6 @@ private slots:
   void pageInfo(int numpages, int currentpage);
   void checkActions();
 
-  /** This is the slot where mouseWheel events are processed that come
-      from the multipage/scrollview. This method calles scroll, a
-      delta-value of 120 (i.e. one notch on a standard wheel mouse)
-      scrolls by two 'lines'. */
-  void wheelEvent(QWheelEvent *);
-
   void slotStartFitTimer();
 
   void doSettings();
@@ -119,6 +126,8 @@ private slots:
 
   void aboutKViewShell();
 
+  void slotEnableMoveTool(bool enable);
+
   // Relay signals to the multipage. We cannot connect to the
   // slots of the multipage directly because than we would have
   // to recreate the whole interface whenever a new multipage is loaded.
@@ -145,6 +154,17 @@ private slots:
   void mp_doGoBack();
   void mp_doGoForward();
 
+  void mp_showFindTextDialog();
+  void mp_findNextText();
+  void mp_findPrevText();
+
+  void mp_doSelectAll();
+  void mp_clearSelection();
+
+  void mp_copyText();
+
+  void mp_exportText();
+
 private:
   void initializeMultiPage();
 
@@ -162,7 +182,7 @@ private:
   KDirWatch *watch;
   KAccel *accel;
   KAction *zoomInAct, *zoomOutAct, *backAct, *forwardAct,
-    *startAct, *endAct, *endDocAct, *markAct, *gotoAct,
+    *startAct, *endAct, *gotoAct,
     *saveAction, *saveAsAction, *printAction, *readUpAct, *readDownAct;
   KAction *backAction;
   KAction *forwardAction;
@@ -172,7 +192,22 @@ private:
     *fitPageAct, *fitHeightAct, *fitWidthAct;
   KSelectAction* viewModeAction;
 
-  KMultiPage *multiPage;
+  KRadioAction* moveModeAction;
+  KRadioAction* selectionModeAction;
+
+  KAction* exportTextAction;
+
+  KAction* copyTextAction;
+  KAction* selectAllAction;
+  KAction* deselectAction;
+  KAction* findTextAction;
+  KAction* findNextTextAction;
+  KAction* findPrevAction;
+  KAction* findNextAction;
+
+  KParts::PartManager* partManager;
+
+  QGuardedPtr<KMultiPage> multiPage;
   // Name of the library of the currently loaded multiPage.
   // Is used to check if it is really necessary to load a new MultiPage.
   QString multiPageLibrary;
@@ -192,7 +227,7 @@ private:
   pageSize  userRequestedPaperSize;
 
   /** stores the current zoom value */
-  class zoom      _zoomVal;
+  Zoom _zoomVal;
   pageSizeDialog *_pageSizeDialog;
 
   QTimer fitTimer;
